# WARNING: Do not edit by hand, this file was generated by Crank:
#
#   https://github.com/gocardless/crank
#

class VerificationDetail(object):
    """A thin wrapper around a verification_detail, providing easy access to its
    attributes.

    Example:
      verification_detail = client.verification_details.get()
      verification_detail.id
    """

    def __init__(self, attributes, api_response):
        self.attributes = attributes
        self.api_response = api_response

    @property
    def address_line1(self):
        return self.attributes.get('address_line1')
  

    @property
    def address_line2(self):
        return self.attributes.get('address_line2')
  

    @property
    def address_line3(self):
        return self.attributes.get('address_line3')
  

    @property
    def city(self):
        return self.attributes.get('city')
  

    @property
    def company_number(self):
        return self.attributes.get('company_number')
  

    @property
    def description(self):
        return self.attributes.get('description')
  

    @property
    def directors(self):
        return self.attributes.get('directors')
  

    @property
    def links(self):
        return self.Links(self.attributes.get('links'))
  

    @property
    def name(self):
        return self.attributes.get('name')
  

    @property
    def postal_code(self):
        return self.attributes.get('postal_code')
  


  

  

  

  

  

  

  

  
    class Links(object):
        """Wrapper for the response's 'links' attribute."""

        def __init__(self, attributes):
            self.attributes = attributes
    
        @property
        def creditor(self):
            return self.attributes.get('creditor')
    
  

  

  

