# WARNING: Do not edit by hand, this file was generated by Crank:
#
#   https://github.com/gocardless/crank
#

class MandateRequestConstraints(object):
    """A thin wrapper around a mandate_request_constraints, providing easy access to its
    attributes.

    Example:
      mandate_request_constraints = client.mandate_request_constraints.get()
      mandate_request_constraints.id
    """

    def __init__(self, attributes, api_response):
        self.attributes = attributes
        self.api_response = api_response

    @property
    def end_date(self):
        return self.attributes.get('end_date')
  

    @property
    def max_amount_per_payment(self):
        return self.attributes.get('max_amount_per_payment')
  

    @property
    def periodic_limits(self):
        return self.attributes.get('periodic_limits')
  

    @property
    def start_date(self):
        return self.attributes.get('start_date')
  


  

  

  

  

