# WARNING: Do not edit by hand, this file was generated by Crank:
#
#   https://github.com/gocardless/crank
#

from . import base_service
from .. import resources
from ..paginator import Paginator
from .. import errors

class MandateRequestConstraintsService(base_service.BaseService):
    """Service class that provides access to the mandate_request_constraints
    endpoints of the GoCardless Pro API.
    """

    RESOURCE_CLASS = resources.MandateRequestConstraints
    RESOURCE_NAME = 'mandate_request_constraints'

